# galileosky

[![CircleCI](https://img.shields.io/circleci/project/github/pikhovkin/galileosky.svg)](https://circleci.com/gh/pikhovkin/galileosky)
[![PyPI](https://img.shields.io/pypi/v/galileosky.svg)](https://pypi.org/project/galileosky/)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/galileosky.svg)
[![PyPI - License](https://img.shields.io/pypi/l/galileosky)](./LICENSE)

Implementation of galileosky protocol

### Installation

```bash
$ pip install galileosky
```

### License

MIT
